svgen.element.html package — docs

Skip to main content
`Ctrl`+`K`

# svgen.element.html package

## Module contents

A module for html-related elements.

class svgen.element.html.Html(title: str, viewport: str = 'width=device-width, initial-scale=1', charset: str = 'utf-8', lang: str = 'en', **kwargs)

  Bases: `Element`

  A class for html elements.

  render(stream: TextIO) → None

    Render a full HTML document to the stream.

svgen.element.html.div(tag: str = 'div', parent: Element = None, allow_no_end_tag: bool = False, front: bool = False, **kwargs) → Element

  Get a new ‘div’ element.